@@ -167,28 +167,31 @@ second character.
     \xXX            Matches the character with 2-digit hex code XX.
     \X              Matches a grapheme.
     \Z              Matches only at the end of the string.
+    \z              Matches only at the end of the string. Alias of \Z.
     \\              Matches a literal backslash.
 
 This module exports the following functions:
-    match      Match a regular expression pattern at the beginning of a string.
-    fullmatch  Match a regular expression pattern against all of a string.
-    search     Search a string for the presence of a pattern.
-    sub        Substitute occurrences of a pattern found in a string using a
-               template string.
-    subf       Substitute occurrences of a pattern found in a string using a
-               format string.
-    subn       Same as sub, but also return the number of substitutions made.
-    subfn      Same as subf, but also return the number of substitutions made.
-    split      Split a string by the occurrences of a pattern. VERSION1: will
-               split at zero-width match; VERSION0: won't split at zero-width
-               match.
-    splititer  Return an iterator yielding the parts of a split string.
-    findall    Find all occurrences of a pattern in a string.
-    finditer   Return an iterator yielding a match object for each match.
-    compile    Compile a pattern into a Pattern object.
-    purge      Clear the regular expression cache.
-    escape     Backslash all non-alphanumerics or special characters in a
-               string.
+    match        Match a regular expression pattern at the beginning of a string.
+    prefixmatch  Match a regular expression pattern at the beginning of a string.
+                 Alias of match.
+    fullmatch    Match a regular expression pattern against all of a string.
+    search       Search a string for the presence of a pattern.
+    sub          Substitute occurrences of a pattern found in a string using a
+                 template string.
+    subf         Substitute occurrences of a pattern found in a string using a
+                 format string.
+    subn         Same as sub, but also return the number of substitutions made.
+    subfn        Same as subf, but also return the number of substitutions made.
+    split        Split a string by the occurrences of a pattern. VERSION1: will
+                 split at zero-width match; VERSION0: won't split at zero-width
+                 match.
+    splititer    Return an iterator yielding the parts of a split string.
+    findall      Find all occurrences of a pattern in a string.
+    finditer     Return an iterator yielding a match object for each match.
+    compile      Compile a pattern into a Pattern object.
+    purge        Clear the regular expression cache.
+    escape       Backslash all non-alphanumerics or special characters in a
+                 string.
 
 Most of the functions support a concurrent parameter: if True, the GIL will be
 released during matching, allowing other Python threads to run concurrently. If
@@ -233,7 +236,7 @@ This module also defines an exception 'error'.
 
 # Public symbols.
 __all__ = ["cache_all", "compile", "DEFAULT_VERSION", "escape", "findall",
-  "finditer", "fullmatch", "match", "purge", "search", "split", "splititer",
+  "finditer", "fullmatch", "match", "prefixmatch", "purge", "search", "split", "splititer",
   "sub", "subf", "subfn", "subn", "template", "Scanner", "A", "ASCII", "B",
   "BESTMATCH", "D", "DEBUG", "E", "ENHANCEMATCH", "S", "DOTALL", "F",
   "FULLCASE", "I", "IGNORECASE", "L", "LOCALE", "M", "MULTILINE", "P", "POSIX",
@@ -241,7 +244,7 @@ __all__ = ["cache_all", "compile", "DEFAULT_VERSION", "escape", "findall",
   "VERSION1", "X", "VERBOSE", "W", "WORD", "error", "Regex", "__version__",
   "__doc__", "RegexFlag"]
 
-__version__ = "2026.1.14"
+__version__ = "2026.2.28"
 
 # --------------------------------------------------------------------
 # Public interface.
@@ -253,6 +256,13 @@ def match(pattern, string, flags=0, pos=None, endpos=None, partial=False,
     pat = _compile(pattern, flags, ignore_unused, kwargs, True)
     return pat.match(string, pos, endpos, concurrent, partial, timeout)
 
+def prefixmatch(pattern, string, flags=0, pos=None, endpos=None, partial=False,
+  concurrent=None, timeout=None, ignore_unused=False, **kwargs):
+    """Try to apply the pattern at the start of the string, returning a match
+    object, or None if no match was found. Alias of match()."""
+    pat = _compile(pattern, flags, ignore_unused, kwargs, True)
+    return pat.match(string, pos, endpos, concurrent, partial, timeout)
+
 def fullmatch(pattern, string, flags=0, pos=None, endpos=None, partial=False,
   concurrent=None, timeout=None, ignore_unused=False, **kwargs):
     """Try to apply the pattern against all of the string, returning a match
